summaryrefslogtreecommitdiffstats
path: root/kernel/arch/arm/mach-shmobile/headsmp-scu.S
diff options
context:
space:
mode:
Diffstat (limited to 'kernel/arch/arm/mach-shmobile/headsmp-scu.S')
-rw-r--r--kernel/arch/arm/mach-shmobile/headsmp-scu.S4
1 files changed, 2 insertions, 2 deletions
diff --git a/kernel/arch/arm/mach-shmobile/headsmp-scu.S b/kernel/arch/arm/mach-shmobile/headsmp-scu.S
index 69df8bfac..fa5248c52 100644
--- a/kernel/arch/arm/mach-shmobile/headsmp-scu.S
+++ b/kernel/arch/arm/mach-shmobile/headsmp-scu.S
@@ -22,7 +22,7 @@
* Boot code for secondary CPUs.
*
* First we turn on L1 cache coherency for our CPU. Then we jump to
* shmobile_invalidate_start that invalidates the cache and hands over control
* to the common ARM startup code.
*/
ENTRY(shmobile_boot_scu)
@@ -36,7 +36,7 @@ ENTRY(shmobile_boot_scu)
bic r2, r2, r3 @ Clear bits of our CPU (Run Mode)
str r2, [r0, #8] @ write back
- b shmobile_invalidate_start
+ b secondary_startup
ENDPROC(shmobile_boot_scu)
.text
@@ -22,7 +22,7 @@
*
* First we turn on L1 cache coherency for our CPU. Then we jump to
- * shmobile_invalidate_start that invalidates the cache and hands over control
+ * secondary_startup that invalidates the cache and hands over control
* to the common ARM startup code.
*/